package com.widget.imagevideobanner.view;

import android.content.Context;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.os.Handler;
import android.os.Looper;
import android.support.v7.widget.AppCompatImageView;
import android.util.Log;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.resource.drawable.GlideDrawable;
import com.bumptech.glide.request.RequestListener;
import com.bumptech.glide.request.target.Target;
import com.widget.imagevideobanner.bean.MediaBean;
import com.widget.imagevideobanner.log.BLogUtil;
import com.widget.imagevideobanner.player.IPlayTarget;
import com.widget.imagevideobanner.utils.QRCodeUtil;
import com.widget.imagevideobanner.utils.ThrowableUtils;

/**
 * 5秒自动切换图片
 */
public class ImageSubView extends AppCompatImageView implements IPlayTarget, RequestListener<String, GlideDrawable>,Runnable {

    private static final int DEFAULT_SWITCH_PAGE_TIME = 5000;

    private OnActionFinishListener onPageChangedListener;

    private final Handler handler = new Handler(Looper.getMainLooper());

    public ImageSubView(Context context) {
        super(context);
    }

    public ImageSubView(Context context, final MediaBean mediaBean, final OnActionFinishListener onPageChangedListener) {
        super(context);
        this.onPageChangedListener = onPageChangedListener;
        setImageUrl(mediaBean.getUrl());
    }

    private void setImageUrl(String url) {
        BLogUtil.log("设置图片链接："+url);
        Drawable err = new BitmapDrawable(getResources(), QRCodeUtil.createQRCodeBitmap(url,100));
        Glide.with(getContext()).load(url)
                .centerCrop()
                .error(err)
                .listener(this)
                .into(this);
    }

    @Override
    public void onActive() {
        BLogUtil.log("图片开始展示");
        handler.removeCallbacks(this);
        handler.postDelayed(this,DEFAULT_SWITCH_PAGE_TIME);
    }

    @Override
    public void inActive() {
        BLogUtil.log("图片结束展示");
        handler.removeCallbacks(this);
    }

    @Override
    public void run() {
        inActive();
        if (null != onPageChangedListener){
            onPageChangedListener.next();
        }
    }

    @Override
    public boolean onException(Exception e, String model, Target<GlideDrawable> target, boolean isFirstResource) {
        BLogUtil.log("图片加载异常"+ThrowableUtils.getFullStackTrace(e));
        return false;
    }

    @Override
    public boolean onResourceReady(GlideDrawable resource, String model, Target<GlideDrawable> target, boolean isFromMemoryCache, boolean isFirstResource) {
        BLogUtil.log("图片加载完成");
        return false;
    }
}
